## What does this PR do?

Brief description.

## Type of change

- [ ] Bug fix
- [ ] New feature
- [ ] New attack samples / regex rules
- [ ] Documentation
- [ ] Performance improvement

## Checklist

- [ ] Tests pass (`pytest tests/ -v`)
- [ ] Lint passes (`ruff check src/ tests/`)
- [ ] Benchmark updated if detection logic changed
- [ ] Documentation updated if needed
